/*****************************************************************************
 * cuckooo - OpenOffice.org nested in KDE                                    *
 *                                                                           *
 * Copyright (C) 2003 Jan Holesovsky <kendy@artax.karlin.mff.cuni.cz>        *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include <kaboutdata.h>
#include <kinstance.h>
#include <klocale.h>
#include <kstddirs.h>
#include <kdebug.h>

#include "../common/about.h"
#include "part.h"
#include "factory.h"

using namespace KOOo;

extern "C"
{
  void* init_libcuckooo()
  {
    return new Factory;
  }
};

KInstance* Factory::s_instance = 0L;
KAboutData* Factory::s_aboutData = 0L;

Factory::Factory(QObject *parent, const char *name)
  : KLibFactory(parent, name)
{
}

Factory::~Factory()
{
  if (s_instance)
  {
    delete s_instance;
    delete s_aboutData;
  }
  s_instance = 0L;
}

QObject* Factory::createObject(QObject *parent, const char *name,
    const char *classname, const QStringList &)
{
  if (parent && !parent->inherits("QWidget"))
  {
    kdError() << "Factory: parent does not inherit QWidget" << endl;
    return 0L;
  }

  Part* part = new Part((QWidget*) parent, name);

  if (QCString(classname) == "KParts::ReadOnlyPart")       // read only
    part->setReadWrite(false);
  else if (QCString(classname) != "KParts::ReadWritePart") // read/write
  {
    kdError() << "Factory: classname isn't ReadOnlyPart nor ReadWritePart !" << endl;
    return 0L;
  }

  emit objectCreated(part);
  return part;
}

KInstance* Factory::instance()
{
  if (!s_instance)
  {
    CUCKOOO_ABOUT_DATA(s_aboutData);
    s_instance = new KInstance(s_aboutData);
  }
  return s_instance;
}

#include "factory.moc"
