/*****************************************************************************
 * cuckooo - OpenOffice.org nested in KDE                                    *
 *                                                                           *
 * Copyright (C) 2003 Jan Holesovsky <kendy@artax.karlin.mff.cuni.cz>        *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#ifndef __KOOo_part_officewidget_h__
#define __KOOo_part_officewidget_h__

#include <qwidget.h>

#include <com/sun/star/bridge/XUnoUrlResolver.hpp>
#include <com/sun/star/frame/XFrame.hpp>
#include <com/sun/star/lang/XMultiServiceFactory.hpp>
#include <osl/process.h>

namespace KOOo
{
  class OfficeWidget : public QWidget
  {
    Q_OBJECT

    protected:
      /**
       * Specifies where the running instance is (or should be) listening,
       * e.g. "socket,host=localhost,port=8100".
       */
      rtl::OUString  m_conSpec;

      oslProcess     m_officeProcess;

      com::sun::star::uno::Reference
	<com::sun::star::bridge::XUnoUrlResolver> m_unoUrlResolver;

      /**
       * The OpenOffice.org splash picture.
       */
      static QPixmap *s_splashPixmap;

      /**
       * Progress to be shown on the splash screen in percents.
       * If < 100, the splash screen will be visible.
       * If < 0, it will be visible, but without any progress meter.
       * If >= 100, it will not be visible.
       */
      int            m_splashProgress;

    public:
      OfficeWidget(const QString &conspec,
	  const QString &officefname = "soffice",
	  const QString &inifile = QString::null,
	  QWidget *parent = 0, const char *name = 0, WFlags f = 0);
      virtual ~OfficeWidget(void);

      bool openFile(QString &name);

      bool closeFile(void);

      /**
       * Progress of loading the office. The splash screen will be drawn if
       * progress is less than 100.
       */
      void setSplashProgress(int progress);

    protected:
      /**
       * Paint splash-screen when connecting to the Office.
       */
      virtual void paintEvent(QPaintEvent *);

    private:
      com::sun::star::uno::Reference
	<com::sun::star::frame::XFrame> m_frame;

      /**
       * Connects to a running OpenOffice.org or starts one, if unable to
       * connect.
       * @param officefname Filename of the OpenOffice.org binary (or wrapper).
       * @param inifile     Resource file specifying the location of .rdb file.
       * @return Success?
       */
      bool initOffice(const rtl::OUString &officefname, const rtl::OUString &inifile);

      /**
       * Returns remote service manager. It tries to connect several times,
       * because it takes some time OOo to start up.
       * @param notimes How many times does it try to connect.
       * @param delay   The delay between 2 tries.
       * @return Reference to the service manager or empty reference.
       */
      com::sun::star::uno::Reference<com::sun::star::lang::XMultiServiceFactory>
	serviceManager(int notimes = 60, int delay = 1);

      bool createFrame(void);

      /**
       * 
       * @param name Filename in form file:///path/filename.ext
       */
      bool loadDocument(const rtl::OUString &name);

      bool hideOfficeControls(void);

      bool hideOfficeControl(int slot_no, const char *name);
      
      bool dispatchUrl(const rtl::OUString &url,
	  const com::sun::star::uno::Sequence<com::sun::star::beans::PropertyValue> &seqProps);

      rtl::OUString getUniqueFrameName(void);
  };
}

#endif // __KOOo_part_officewidget_h__
