/*****************************************************************************
 * cuckooo - OpenOffice.org nested in KDE                                    *
 *                                                                           *
 * Copyright (C) 2003 Jan Holesovsky <kendy@artax.karlin.mff.cuni.cz>        *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include <cstdlib>

#include <qfile.h>
#include <qmultilineedit.h>
#include <qwidget.h>

#include <kaction.h>
#include <kconfig.h>
#include <kdebug.h>
#include <kinstance.h>
#include <klocale.h>
#include <kstandarddirs.h>

#include "part.h"
#include "officewidget.h"

using namespace KOOo;

Office *Part::s_office = NULL;

Part::Part(QWidget *parent, const char *name)
  : KParts::ReadWritePart(parent, name)
{
  // Menus and toolbars
  setXMLFile("cuckooopartui.rc");

  KInstance *instance = new KInstance("part");
  setInstance(instance);

  // Location of the UNO .ini file
  QString qInifile = locate("data", "cuckooo/cuckooopart.ini");
  qInifile.prepend("file://");
  kdDebug() << "UNO .ini file: " << qInifile << endl;

  // Read the configuration file
  KConfig *config = new KConfig("cuckooorc");
  config->setGroup("OpenOffice.org");
  QString qOfficeExe = config->readPathEntry("Executable", "soffice");
  delete config;

  if ('/' == qOfficeExe.at(0))
    qOfficeExe.prepend("file://");
  
  char *userName = getenv("USER");
  if (!userName)
    userName = getenv("LOGNAME");
  QString qConSpec = QString("pipe,name=%1_cuckooo-OOo_pipe").arg(userName);
  free(userName);

  // Create the main widget
  m_officeWidget = new OfficeWidget(qConSpec, qOfficeExe, qInifile,
      parent, "officewidget");
  m_officeWidget->setFocus();
  setWidget(m_officeWidget);

  // Setup actions
  /*TODO
  (void)new KAction(i18n("Select All"), "edit", 0, this,
		    SLOT(slotSelectAll()), actionCollection(), "selectall");
  */

  // The default edit mode
  // FIXME: true (when editing will be possible)
  setReadWrite(false);
}

void Part::setReadWrite(bool rw)
{
  /*TODO
  m_officeWidget->setReadOnly(!rw);
  if (rw)
    connect( m_officeWidget, SIGNAL( textChanged() ), this, SLOT( setModified() ) );
  else
    disconnect( m_officeWidget, SIGNAL( textChanged() ), this, SLOT( setModified() ) );
  */

  ReadWritePart::setReadWrite(rw); // call the parent implementation
}

bool Part::openFile()
{
  QString s = m_file;
  if (s.left(5) != "file:")
    s.prepend("file://");
  
  kdDebug() << "Open: " << s << endl;
  m_officeWidget->openFile(s);

  return true;
}

bool Part::saveFile()
{
  if (!isReadWrite())
    return false;

  // TODO

  return false;
}
